import pandas as pd

def export(movies_collection):

	output_name = "output.xlsx"

	all_data = []

	for movie in movies_collection:
		movie_frame = pd.DataFrame({
			"seed": movie.seed,
			"id": movie.id,
			"url": movie.url,
			"title": movie.title,
			"year": movie.year,
			"genre": movie.genre,
			"duration": movie.duration,
			"rating": movie.rating,
			"n_votes": movie.n_votes,
			"country": movie.country,
			}, index=[0])
		all_data.append(movie_frame)

	all_data = pd.concat(all_data, ignore_index=True)
	all_data.to_excel(output_name)
	print("Job Done!")
	return all_data



class Movie:
	
	def __init__(self,
		seed,
		id,
		url,
		title,
		year,
		genre,
		duration,
		rating,
		n_votes,
		country,
		related_films,
		):
		self.seed = seed
		self.id = id
		self.url = url
		self.title = title
		self.year = year
		self.genre = genre
		self.duration = duration
		self.rating = rating
		self.n_votes = n_votes
		self.country = country
		self.related_films = related_films



import requests
from bs4 import  BeautifulSoup
from tqdm import tqdm
from time import sleep

from . import movie_class as mv

def get_related(movies_objects_list, ammount, message):

	related_movies_objects_list = []

	pbar = tqdm(total=ammount, bar_format='{l_bar}{bar:20}{r_bar}{bar:-20b}', desc=message)

	for movie_object in movies_objects_list:

		seed = movie_object.id

		related_films = movie_object.related_films

		for related_film in related_films:

			url = "https://www.imdb.com/title/{}/".format(related_film)
			page = requests.get(url)
			soup = BeautifulSoup(page.content, 'html.parser')

			#The Basics)
			film_id = related_film
			film_url = url

			#Film Title
			title = soup.find_all("h1")
			try:
				only_title = str(title[0]).split(">")[1].split("<")[0].replace("\xa0", "")
			except IndexError:
				only_title = str(title[0]).split(">")[1].split("<")[0]

			#Year
			try:
				year = str(title[0]).split(">")[3].split("<")[0]
			except IndexError:
				year = "Nan"

			#Main Info
			info = soup.find_all("div", class_="subtext")
			genre = str(info[0]).split(">")[8].split("<")[0]
			try:
				duration = str(info[0]).split(">")[4].split("\n")[1].strip(" ")
			except IndexError:
				duration = "Nan"

			#rating
			rating = soup.find_all("span", itemprop="ratingValue")
			clean_rating = str(rating[0]).split(">")[1].split("<")[0]
			float_rating = float(clean_rating)

			#votes
			votes = soup.find_all("span", itemprop="ratingCount")
			only_votes = str(votes[0]).split(">")[1].split("<")[0]
			only_votes_clean = only_votes.replace(",", "")
			only_votes = int(only_votes_clean)

			#Country
			country = soup.find_all("div", class_="txt-block")
			only_country = str(country).split("/search/title?country_of_origin")[1].split(">")[1].split("<")[0]

			#Related
			related_films = soup.find_all("div", class_="rec_item")
			transactional_related_films = []
			for related_film in related_films:
				only_film = str(related_film).split("data-tconst=")[1].split(">")[0].split('"')[1]
				transactional_related_films.append(only_film)

			related_movie_object = mv.Movie(
				seed,
				film_id,
				film_url,
				only_title,
				year,
				genre,
				duration,
				float_rating,
				only_votes,
				only_country,
				transactional_related_films,
				)
			
			related_movies_objects_list.append(related_movie_object)

			pbar.update()

	return related_movies_objects_list

def controller(movies_objects_list, related):

	ammount = len(movies_objects_list)*12
	print("Total access points: "+str(len(movies_objects_list)))
	print("Total Related Movies: "+str(ammount))
	print("Please remember: Runtime depends on website response speed, be patient :)")
	print("Starting the job...")

	movies = []

	message = "1st Iteration -->"
	related_movies = get_related(movies_objects_list, ammount, message)
	movies.extend(related_movies)

	if related == True:
		new_ammount = len(movies)*12
		second_message = "2nd Iteration -->"
		more_related_movies = get_related(related_movies, new_ammount, second_message)
		movies.extend(more_related_movies)

	tqdm._instances.pop().close() # This close all tqdm instances and prevent from re-print
	
	return movies




from . import films as f
from . import related_films as r
from . import dataframing as df

films = [""] #You Can place a single ID or a list of them
related = False

def main(films, related):

	movies_collection = []

	movies = f.scrape(films)
	movies_collection.extend(movies)

	related_movies = r.controller(movies, related)
	movies_collection.extend(related_movies)

	data = df.export(movies_collection)

if __name__ == "__main__":
	main(films, related)


import setuptools


setuptools.setup(name='imdb_films_scraper',
      version="1.0.3",
      url = "https://github.com/AdriaPadilla/imdb_films_scraper/", 
      description='Scrape Film data from IMDB',
      author='Adrian Padilla',
      author_email='adrian.padilla.m@gmail.com',
      packages=setuptools.find_packages(),
      install_requires=["numpy", "pandas", "requests", "beautifulsoup4", "openpyxl", "tqdm"],
      classifiers=[
       "Programming Language :: Python :: 3",
       "License :: OSI Approved :: MIT License",
       "Operating System :: OS Independent",
       ],
     )



import requests
from bs4 import  BeautifulSoup

from . import movie_class as mv

movies_objects_list = []

def scrape(films):

	for film in films:
		url = "https://www.imdb.com/title/{}/".format(film)
		page = requests.get(url)
		soup = BeautifulSoup(page.content, 'html.parser')

		#The Basics)
		film_id = film
		film_url = url

		#Film Title
		title = soup.find_all("h1")
		try:
			only_title = str(title[0]).split(">")[1].split("<")[0].replace("\xa0", "")
		except IndexError:
			only_title = str(title[0]).split(">")[1].split("<")[0]

		#Year
		year = str(title[0]).split(">")[3].split("<")[0]

		#Main Info
		info = soup.find_all("div", class_="subtext")
		genre = str(info[0]).split(">")[8].split("<")[0]
		duration = str(info[0]).split(">")[4].split("\n")[1].strip(" ")

		#rating
		rating = soup.find_all("span", itemprop="ratingValue")
		clean_rating = str(rating[0]).split(">")[1].split("<")[0]
		float_rating = float(clean_rating)

		#votes
		votes = soup.find_all("span", itemprop="ratingCount")
		only_votes = str(votes[0]).split(">")[1].split("<")[0]
		only_votes_clean = only_votes.replace(",", "")
		only_votes = int(only_votes_clean)

		#Country
		country = soup.find_all("div", class_="txt-block")
		only_country = str(country).split("/search/title?country_of_origin")[1].split(">")[1].split("<")[0]

		#Related
		related_films = soup.find_all("div", class_="rec_item")
		transactional_related_films = []
		for related_film in related_films:
			only_film = str(related_film).split("data-tconst=")[1].split(">")[0].split('"')[1]
			transactional_related_films.append(only_film)

		movie_object = mv.Movie(
			"user",
			film_id,
			film_url,
			only_title,
			year,
			genre,
			duration,
			float_rating,
			only_votes,
			only_country,
			transactional_related_films,
			)
		movies_objects_list.append(movie_object)
		print("Starting Film: "+movie_object.title+" / "+movie_object.year+" / "+"rating: "+str(movie_object.rating))

	return movies_objects_list






